@@ -24,7 +24,7 @@ except ImportError:
 
 from tlslite import TLSConnection, Fault, HandshakeSettings, \
     X509, X509CertChain, IMAP4_TLS, VerifierDB, Session, SessionCache, \
-    parsePEMKey, \
+    parsePEMKey, constants, \
     AlertDescription, HTTPTLSConnection, TLSSocketServerMixIn, \
     POP3_TLS, m2cryptoLoaded, pycryptoLoaded, gmpyLoaded, tackpyLoaded, \
     Checker, __version__
@@ -95,7 +95,7 @@ def clientTestCmd(argv):
     test = 0
 
     badFault = False
-    
+
     print("Test 0 - anonymous handshake")
     connection = connect()
     connection.handshakeClientAnonymous()
@@ -120,6 +120,16 @@ def clientTestCmd(argv):
     assert(isinstance(connection.session.serverCertChain, X509CertChain))
     connection.close()    
 
+    print("Test 1.b - good X509, RC4-MD5")
+    connection = connect()
+    settings = HandshakeSettings()
+    settings.macNames = ["md5"]
+    connection.handshakeClientCert(settings=settings)
+    testConnClient(connection)    
+    assert(isinstance(connection.session.serverCertChain, X509CertChain))
+    assert(connection.session.cipherSuite == constants.CipherSuite.TLS_RSA_WITH_RC4_128_MD5)
+    connection.close()
+
     if tackpyLoaded:
                     
         settings = HandshakeSettings()
@@ -250,7 +260,7 @@ def clientTestCmd(argv):
         if alert.description != AlertDescription.bad_record_mac:
             raise
     connection.close()
-
+    
     print("Test 21 - HTTPS test X.509")
     address = address[0], address[1]+1
     if hasattr(socket, "timeout"):
@@ -447,6 +457,11 @@ def serverTestCmd(argv):
     def connect():
         return TLSConnection(lsock.accept()[0])
 
+    x509Cert = X509().parse(open(os.path.join(dir, "serverX509Cert.pem")).read())
+    x509Chain = X509CertChain([x509Cert])
+    s = open(os.path.join(dir, "serverX509Key.pem")).read()
+    x509Key = parsePEMKey(s, private=True)
+
     print("Test 0 - Anonymous server handshake")
     connection = connect()
     connection.handshakeServer(anon=True)
@@ -454,11 +469,6 @@ def serverTestCmd(argv):
     connection.close() 
     
     print("Test 1 - good X.509")
-    x509Cert = X509().parse(open(os.path.join(dir, "serverX509Cert.pem")).read())
-    x509Chain = X509CertChain([x509Cert])
-    s = open(os.path.join(dir, "serverX509Key.pem")).read()
-    x509Key = parsePEMKey(s, private=True)
-
     connection = connect()
     connection.handshakeServer(certChain=x509Chain, privateKey=x509Key)
     assert(connection.session.serverName == address[0])    
@@ -473,6 +483,15 @@ def serverTestCmd(argv):
     connection.handshakeServer(certChain=x509Chain, privateKey=x509Key, settings=settings)
     testConnServer(connection)
     connection.close()            
+
+    print("Test 1.b - good X.509, RC4-MD5")
+    connection = connect()
+    settings = HandshakeSettings()
+    settings.macNames = ["sha", "md5"]
+    settings.cipherNames = ["rc4"]
+    connection.handshakeServer(certChain=x509Chain, privateKey=x509Key, settings=settings)
+    testConnServer(connection)
+    connection.close()            
     
     if tackpyLoaded:
         tack = Tack.createFromPem(open("./TACK1.pem", "rU").read())
