@@ -22,7 +22,7 @@ import socket
 import errno
 import traceback
 
-class _ConnectionState:
+class _ConnectionState(object):
     def __init__(self):
         self.macContext = None
         self.encContext = None
@@ -35,7 +35,7 @@ class _ConnectionState:
         return w.bytes
 
 
-class TLSRecordLayer:
+class TLSRecordLayer(object):
     """
     This class handles data transmission for a TLS connection.
 
@@ -109,7 +109,8 @@ class TLSRecordLayer:
 
         #Buffers for processing messages
         self._handshakeBuffer = []
-        self._readBuffer = b""
+        self.clearReadBuffer()
+        self.clearWriteBuffer()
 
         #Handshake digests
         self._handshake_md5 = hashlib.md5()
@@ -145,6 +146,13 @@ class TLSRecordLayer:
         #Fault we will induce, for testing purposes
         self.fault = None
 
+    def clearReadBuffer(self):
+        self._readBuffer = b''
+
+    def clearWriteBuffer(self):
+        self._send_writer = None
+
+
     #*********************************************************
     # Public Functions START
     #*********************************************************
@@ -219,6 +227,14 @@ class TLSRecordLayer:
             self._shutdown(False)
             raise
 
+    def unread(self, b):
+        """Add bytes to the front of the socket read buffer for future
+        reading. Be careful using this in the context of select(...): if you
+        unread the last data from a socket, that won't wake up selected waiters,
+        and those waiters may hang forever.
+        """
+        self._readBuffer = b + self._readBuffer
+
     def write(self, s):
         """Write some data to the TLS connection.
 
@@ -248,7 +264,7 @@ class TLSRecordLayer:
         """
         try:
             if self.closed:
-                raise ValueError()
+                raise TLSClosedConnectionError("attempt to write to closed connection")
 
             index = 0
             blockSize = 16384
@@ -269,7 +285,7 @@ class TLSRecordLayer:
                 index += 1
         except GeneratorExit:
             raise
-        except:
+        except Exception:
             self._shutdown(False)
             raise
 
@@ -487,7 +503,6 @@ class TLSRecordLayer:
     def _shutdown(self, resumable):
         self._writeState = _ConnectionState()
         self._readState = _ConnectionState()
-        #Don't do this: self._readBuffer = ""
         self.version = (0,0)
         self._versionCheck = False
         self.closed = True
@@ -596,7 +611,7 @@ class TLSRecordLayer:
             try:
                 bytesSent = self.sock.send(s) #Might raise socket.error
             except socket.error as why:
-                if why.args[0] == errno.EWOULDBLOCK:
+                if why.args[0] in (errno.EWOULDBLOCK, errno.EAGAIN):
                     yield 1
                     continue
                 else:
@@ -814,7 +829,7 @@ class TLSRecordLayer:
             try:
                 s = self.sock.recv(recordHeaderLength-len(b))
             except socket.error as why:
-                if why.args[0] == errno.EWOULDBLOCK:
+                if why.args[0] in (errno.EWOULDBLOCK, errno.EAGAIN):
                     yield 0
                     continue
                 else:
@@ -854,7 +869,7 @@ class TLSRecordLayer:
             try:
                 s = self.sock.recv(r.length - len(b))
             except socket.error as why:
-                if why.args[0] == errno.EWOULDBLOCK:
+                if why.args[0] in (errno.EWOULDBLOCK, errno.EAGAIN):
                     yield 0
                     continue
                 else:
@@ -1030,27 +1045,30 @@ class TLSRecordLayer:
     def _calcPendingStates(self, cipherSuite, masterSecret,
             clientRandom, serverRandom, implementations):
         if cipherSuite in CipherSuite.aes128Suites:
-            macLength = 20
             keyLength = 16
             ivLength = 16
             createCipherFunc = createAES
         elif cipherSuite in CipherSuite.aes256Suites:
-            macLength = 20
             keyLength = 32
             ivLength = 16
             createCipherFunc = createAES
         elif cipherSuite in CipherSuite.rc4Suites:
-            macLength = 20
             keyLength = 16
             ivLength = 0
             createCipherFunc = createRC4
         elif cipherSuite in CipherSuite.tripleDESSuites:
-            macLength = 20
             keyLength = 24
             ivLength = 8
             createCipherFunc = createTripleDES
         else:
             raise AssertionError()
+            
+        if cipherSuite in CipherSuite.shaSuites:
+            macLength = 20
+            digestmod = hashlib.sha1        
+        elif cipherSuite in CipherSuite.md5Suites:
+            macLength = 16
+            digestmod = hashlib.md5
 
         if self.version == (3,0):
             createMACFunc = createMAC_SSL
@@ -1082,8 +1100,10 @@ class TLSRecordLayer:
         serverKeyBlock = p.getFixBytes(keyLength)
         clientIVBlock  = p.getFixBytes(ivLength)
         serverIVBlock  = p.getFixBytes(ivLength)
-        clientPendingState.macContext = createMACFunc(compatHMAC(clientMACBlock))
-        serverPendingState.macContext = createMACFunc(compatHMAC(serverMACBlock))
+        clientPendingState.macContext = createMACFunc(
+            compatHMAC(clientMACBlock), digestmod=digestmod)
+        serverPendingState.macContext = createMACFunc(
+            compatHMAC(serverMACBlock), digestmod=digestmod)
         clientPendingState.encContext = createCipherFunc(clientKeyBlock,
                                                          clientIVBlock,
                                                          implementations)
